@@ -192,13 +192,17 @@ on_first_timer (SeahorseKeyManager* self)
 #endif
 
 static void
-on_clear_clicked (GtkEntry* entry, GtkEntryIconPosition icon_pos, GdkEvent* event, gpointer user_data)
+on_clear_clicked (GtkEntry* entry,
+                  GtkEntryIconPosition icon_pos,
+                  GdkEvent* event,
+                  gpointer user_data)
 {
 	gtk_entry_set_text (entry, "");
 }
 
 static void 
-on_filter_changed (GtkEntry* entry, SeahorseKeyManager* self) 
+on_filter_changed (GtkEntry* entry,
+                   SeahorseKeyManager* self)
 {
 	const gchar *text;
 
@@ -207,6 +211,20 @@ on_filter_changed (GtkEntry* entry, SeahorseKeyManager* self)
 
 	text = gtk_entry_get_text (entry);
 	g_object_set (self->pv->store, "filter", text, NULL);
+
+	if (text == NULL || g_str_equal (text, "")) {
+		g_object_set (G_OBJECT (entry),
+		              "secondary-icon-name", "edit-find-symbolic",
+		              "secondary-icon-activatable", FALSE,
+		              "secondary-icon-sensitive", FALSE,
+		              NULL);
+	} else {
+		g_object_set (G_OBJECT (entry),
+		              "secondary-icon-name", "edit-clear-symbolic",
+		              "secondary-icon-activatable", TRUE,
+		              "secondary-icon-sensitive", TRUE,
+		              NULL);
+	}
 }
 
 static void 
@@ -511,8 +529,8 @@ static const GtkActionEntry GENERAL_ACTIONS[] = {
 };
 
 static const GtkToggleActionEntry SIDEBAR_ACTIONS[] = {
-	{ "view-places", NULL, N_("P_laces"), NULL,
-	  N_("Show places sidebar"), NULL, FALSE },
+	{ "view-sidebar", NULL, N_("By _keyring"), NULL,
+	  N_("Show sidebar listing keyrings"), NULL, FALSE },
 };
 
 static const GtkRadioActionEntry VIEW_RADIO_ACTIONS[] = {
@@ -594,6 +612,9 @@ setup_sidebar (SeahorseKeyManager *self)
 	g_signal_connect (panes, "unrealize", G_CALLBACK (on_panes_unrealize), self);
 	g_signal_connect (self->pv->sidebar, "context-menu", G_CALLBACK (on_sidebar_popup_menu), self);
 
+	gtk_widget_set_size_request (gtk_paned_get_child1 (GTK_PANED (panes)), 50, -1);
+	gtk_widget_set_size_request (gtk_paned_get_child2 (GTK_PANED (panes)), 150, -1);
+
 	backends = seahorse_sidebar_get_backends (self->pv->sidebar);
 	for (l = backends; l != NULL; l = g_list_next (l)) {
 		actions = NULL;
@@ -612,7 +633,7 @@ setup_sidebar (SeahorseKeyManager *self)
 	gtk_action_group_set_translation_domain (actions, GETTEXT_PACKAGE);
 	gtk_action_group_add_toggle_actions (actions, SIDEBAR_ACTIONS,
 	                                     G_N_ELEMENTS (SIDEBAR_ACTIONS), self);
-	action = gtk_action_group_get_action (actions, "view-places");
+	action = gtk_action_group_get_action (actions, "view-sidebar");
 	g_settings_bind (self->pv->settings, "sidebar-visible",
 	                 action, "active",
 	                 G_SETTINGS_BIND_DEFAULT);
@@ -625,7 +646,7 @@ setup_sidebar (SeahorseKeyManager *self)
 	seahorse_catalog_include_actions (SEAHORSE_CATALOG (self), actions);
 	g_object_unref (actions);
 
-	g_settings_bind (self->pv->settings, "places-selected",
+	g_settings_bind (self->pv->settings, "keyrings-selected",
 	                 self->pv->sidebar, "selected-uris",
 	                 G_SETTINGS_BIND_DEFAULT);
 
@@ -740,23 +761,11 @@ seahorse_key_manager_constructed (GObject *object)
 		}
 	}
 
-	gtk_entry_set_icon_from_icon_name (self->pv->filter_entry,
-					   GTK_ENTRY_ICON_PRIMARY,
-					   GTK_STOCK_FIND);
-	gtk_entry_set_icon_from_icon_name (self->pv->filter_entry,
-					   GTK_ENTRY_ICON_SECONDARY,
-					   GTK_STOCK_CLEAR);
-
-	gtk_entry_set_icon_activatable (self->pv->filter_entry,
-					GTK_ENTRY_ICON_PRIMARY, FALSE);
-	gtk_entry_set_icon_activatable (self->pv->filter_entry,
-					GTK_ENTRY_ICON_SECONDARY, TRUE);
-
+	on_filter_changed (self->pv->filter_entry, self);
 	gtk_entry_set_width_chars (self->pv->filter_entry, 30);
-
 	g_signal_connect (self->pv->filter_entry, "icon-release",
-			  G_CALLBACK (on_clear_clicked), NULL);
-	
+	                  G_CALLBACK (on_clear_clicked), NULL);
+
 	/* For the filtering */
 	g_signal_connect_object (GTK_EDITABLE (self->pv->filter_entry), "changed", 
 	                         G_CALLBACK (on_filter_changed), self, 0);
