@@ -23,10 +23,20 @@
 #include "config.h"
 
 #include "seahorse-ssh-actions.h"
+#include "seahorse-ssh-deleter.h"
+#include "seahorse-ssh-dialogs.h"
+#include "seahorse-ssh-exporter.h"
 #include "seahorse-ssh-key.h"
 #include "seahorse-ssh-operation.h"
 #include "seahorse-ssh-source.h"
 
+#include "seahorse-deletable.h"
+#include "seahorse-exportable.h"
+#include "seahorse-icons.h"
+#include "seahorse-place.h"
+#include "seahorse-validity.h"
+#include "seahorse-viewable.h"
+
 #include <gcr/gcr.h>
 
 #include <glib.h>
@@ -36,11 +46,6 @@
 #include <errno.h>
 #include <string.h>
 
-
-#include "seahorse-place.h"
-#include "seahorse-icons.h"
-#include "seahorse-validity.h"
-
 enum {
     PROP_0,
     PROP_KEY_DATA,
@@ -52,7 +57,17 @@ enum {
     PROP_LENGTH
 };
 
-G_DEFINE_TYPE (SeahorseSSHKey, seahorse_ssh_key, SEAHORSE_TYPE_OBJECT);
+static void       seahorse_ssh_key_deletable_iface       (SeahorseDeletableIface *iface);
+
+static void       seahorse_ssh_key_exportable_iface      (SeahorseExportableIface *iface);
+
+static void       seahorse_ssh_key_viewable_iface        (SeahorseViewableIface *iface);
+
+G_DEFINE_TYPE_WITH_CODE (SeahorseSSHKey, seahorse_ssh_key, SEAHORSE_TYPE_OBJECT,
+                         G_IMPLEMENT_INTERFACE (SEAHORSE_TYPE_EXPORTABLE, seahorse_ssh_key_exportable_iface);
+                         G_IMPLEMENT_INTERFACE (SEAHORSE_TYPE_DELETABLE, seahorse_ssh_key_deletable_iface);
+                         G_IMPLEMENT_INTERFACE (SEAHORSE_TYPE_VIEWABLE, seahorse_ssh_key_viewable_iface);
+);
 
 /* -----------------------------------------------------------------------------
  * INTERNAL 
@@ -295,9 +310,44 @@ seahorse_ssh_key_class_init (SeahorseSSHKeyClass *klass)
                            0, G_MAXUINT, 0, G_PARAM_READABLE));
 }
 
-/* -----------------------------------------------------------------------------
- * PUBLIC METHODS
- */
+static GList *
+seahorse_ssh_key_create_exporters (SeahorseExportable *exportable,
+                                   SeahorseExporterType type)
+{
+	return g_list_append (NULL, seahorse_ssh_exporter_new (G_OBJECT (exportable), FALSE));
+}
+
+static void
+seahorse_ssh_key_exportable_iface (SeahorseExportableIface *iface)
+{
+	iface->create_exporters = seahorse_ssh_key_create_exporters;
+}
+
+static SeahorseDeleter *
+seahorse_ssh_key_create_deleter (SeahorseDeletable *deletable)
+{
+	SeahorseSSHKey *self = SEAHORSE_SSH_KEY (deletable);
+	return seahorse_ssh_deleter_new (self);
+}
+
+static void
+seahorse_ssh_key_deletable_iface (SeahorseDeletableIface *iface)
+{
+	iface->create_deleter = seahorse_ssh_key_create_deleter;
+}
+
+static void
+seahorse_ssh_key_show_viewer (SeahorseViewable *viewable,
+                              GtkWindow *parent)
+{
+	seahorse_ssh_key_properties_show (SEAHORSE_SSH_KEY (viewable), parent);
+}
+
+static void
+seahorse_ssh_key_viewable_iface (SeahorseViewableIface *iface)
+{
+	iface->show_viewer = seahorse_ssh_key_show_viewer;
+}
 
 SeahorseSSHKey* 
 seahorse_ssh_key_new (SeahorsePlace *place,
@@ -311,6 +361,13 @@ seahorse_ssh_key_new (SeahorsePlace *place,
     return skey;
 }
 
+SeahorseSSHKeyData *
+seahorse_ssh_key_get_data (SeahorseSSHKey *self)
+{
+	g_return_val_if_fail (SEAHORSE_IS_SSH_KEY (self), NULL);
+	return self->keydata;
+}
+
 guint 
 seahorse_ssh_key_get_algo (SeahorseSSHKey *skey)
 {
